@@ -36,7 +36,7 @@ int main(int argc, char **argv)
 {
     KAboutData about("dolphin",
                      I18N_NOOP("Dolphin"),
-                     "0.8.1",
+                     "0.8.2",
                      I18N_NOOP("File Manager"),
                      KAboutData::License_GPL,
                      "(C) 2006 Peter Penz");
@@ -49,7 +49,7 @@ int main(int argc, char **argv)
     about.addAuthor("Orville Bennett", I18N_NOOP("Documentation"), "obennett@hartford.edu");
     about.addCredit("Aaron J. Seigo", I18N_NOOP("... for the great support and the amazing patches"));
     about.addCredit("Patrice Tremblay and Gregor Kalisnik", I18N_NOOP("... for their patches"));
-    about.addCredit("Ain, Itai, Ivan, Stephane, Patrice, Piotr and Stefano",
+    about.addCredit("Ain, Itai, Ivan, Jannick, Stephane, Patrice, Piotr and Stefano",
                     I18N_NOOP("... for their translations"));
 
     KCmdLineArgs::init(argc, argv, &about);
